@@ -402,7 +402,7 @@ class GrpcHandler(AbsMilvus):
         response = rf.result()
         if response.error_code != 0:
             raise BaseException(response.error_code, response.reason)
-        self.load_partitions("", collection_name, [partition_tag], timeout=timeout)
+        # self.load_partitions("", collection_name, [partition_tag], timeout=timeout)
         # return Status(response.status.error_code, response.status.reason)
 
     @error_handler()
@@ -462,6 +462,8 @@ class GrpcHandler(AbsMilvus):
         #     raise ParamError("The value of key 'insert_param' is invalid")
         if insert_param and not isinstance(insert_param, milvus_types.RowBatch):
             raise ParamError("The value of key 'insert_param' is invalid")
+        if not isinstance(entities, list):
+            raise ParamError("None entities, please provide valid entities.")
 
         collection_request = Prepare.describe_collection_request(collection_name)
         rf = self._stub.DescribeCollection.future(collection_request, wait_for_ready=True, timeout=timeout)
@@ -648,21 +650,36 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler()
     def create_index(self, collection_name, field_name, params, timeout=None, **kwargs):
+        # sync flush
+        _async = kwargs.get("_async", False)
+        kwargs["_async"] = False
         self.flush([collection_name], timeout, **kwargs)
+
         index_param = Prepare.create_index__request(collection_name, field_name, params)
         future = self._stub.CreateIndex.future(index_param, wait_for_ready=True, timeout=timeout)
-        if kwargs.get('_async', False):
-            cb = kwargs.get("_callback", None)
-            return CreateIndexFuture(future, cb)
+
+        if _async:
+            def _check():
+                if kwargs.get("sync", True):
+                    if not self.wait_for_creating_index(collection_name=collection_name, field_name=field_name):
+                        raise BaseException(Status.UNEXPECTED_ERROR, "create index failed")
+
+            index_future = CreateIndexFuture(future)
+            index_future.add_callback(_check)
+            user_cb = kwargs.get("_callback", None)
+            if user_cb:
+                index_future.add_callback(user_cb)
+            return index_future
+
         status = future.result()
 
         if status.error_code != 0:
             raise BaseException(status.error_code, status.reason)
-        sync = kwargs.get("sync", True)
-        if sync:
+
+        if kwargs.get("sync", True):
             if not self.wait_for_creating_index(collection_name=collection_name, field_name=field_name):
-                raise BaseException(status.error_code, "create index failed")
-            self.wait_for_load_index_done(collection_name, timeout, **kwargs)
+                raise BaseException(Status.UNEXPECTED_ERROR, "create index failed")
+
         return Status(status.error_code, status.reason)
 
     @error_handler(None)
@@ -673,17 +690,12 @@ class GrpcHandler(AbsMilvus):
         response = rf.result()
         status = response.status
         if status.error_code == 0:
-            index_descriptions = response.index_descriptions
-            if not index_descriptions:
-                raise BaseException(status.error_code, status.reason)
-            else:
-                info_dict = dict()
-                for kv in index_descriptions[0].params:
-                    value = kv.value
-                    if kv.key == 'params':
-                        value = json.loads(kv.value)
-                    info_dict[kv.key] = value
-                return info_dict
+            info_dict = {kv.key: kv.value for kv in response.index_descriptions[0].params}
+            if info_dict.get("params", None):
+                info_dict["params"] = json.loads(info_dict["params"])
+            return info_dict
+        if status.error_code == Status.INDEX_NOT_EXIST:
+            return None
         raise BaseException(status.error_code, status.reason)
 
     @error_handler(common_types.IndexState.FAILED)
@@ -752,9 +764,21 @@ class GrpcHandler(AbsMilvus):
         request = Prepare.load_partitions(db_name=db_name, collection_name=collection_name,
                                           partition_names=partition_names)
         future = self._stub.LoadPartitions.future(request, wait_for_ready=True, timeout=timeout)
+
         if kwargs.get("_async", False):
-            cb = kwargs.get("_callback", None)
-            return LoadPartitionsFuture(future, cb)
+            def _check():
+                if kwargs.get("sync", True):
+                    self.wait_for_loading_partitions(collection_name, partition_names)
+
+            load_partitions_future = LoadPartitionsFuture(future)
+            load_partitions_future.add_callback(_check)
+
+            user_cb = kwargs.get("_callback", None)
+            if user_cb:
+                load_partitions_future.add_callback(user_cb)
+
+            return load_partitions_future
+
         response = future.result()
         if response.error_code != 0:
             raise BaseException(response.error_code, response.reason)
@@ -795,7 +819,7 @@ class GrpcHandler(AbsMilvus):
     def release_partitions(self, db_name, collection_name, partition_names, timeout=30):
         request = Prepare.release_partitions(db_name, collection_name,
                                              partition_names)
-        rf = self._stub.ReleasePartions().future(request, wait_for_ready=True, timeout=timeout)
+        rf = self._stub.ReleasePartitions.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
         if response.error_code != 0:
             raise BaseException(response.error_code, response.reason)
@@ -840,12 +864,24 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler()
     def flush(self, collection_name_array: list, timeout=None, **kwargs):
-        print("CZS::::::::::::::::::::::::::::", collection_name_array)
         request = Prepare.flush_param(collection_name_array)
         future = self._stub.Flush.future(request, wait_for_ready=True, timeout=timeout)
+
         if kwargs.get("_async", False):
-            cb = kwargs.get("_callback", None)
-            return FlushFuture(future, cb)
+            def _check():
+                if kwargs.get("sync", True):
+                    for collection_name in collection_name_array:
+                        self.wait_for_flushed(collection_name)
+
+            flush_future = FlushFuture(future)
+            flush_future.add_callback(_check)
+
+            user_cb = kwargs.get("_callback", None)
+            if user_cb:
+                flush_future.add_callback(user_cb)
+
+            return flush_future
+
         response = future.result()
         if response.error_code != 0:
             raise BaseException(response.error_code, response.reason)
@@ -861,3 +897,9 @@ class GrpcHandler(AbsMilvus):
         response = future.result()
         if response.error_code != 0:
             raise BaseException(response.error_code, response.reason)
+
+    @error_handler(False)
+    def fake_register_link(self, timeout=30):
+        request = Prepare.empty()
+        future = self._stub.RegisterLink.future(request, wait_for_ready=True, timeout=timeout)
+        return future.result().status.error_code == 0
