@@ -107,7 +107,8 @@ class Prepare:
 
                 schema.fields.append(field_schema)
 
-        return milvus_types.CreateCollectionRequest(collection_name=collection_name, schema=bytes(schema.SerializeToString()))
+        return milvus_types.CreateCollectionRequest(collection_name=collection_name,
+                                                    schema=bytes(schema.SerializeToString()))
 
     @classmethod
     def drop_collection_request(cls, collection_name):
@@ -160,7 +161,7 @@ class Prepare:
         if not isinstance(partition_tag, str):
             raise ParamError("partition_tag must be of str type")
         return milvus_types.PartitionName(collection_name=collection_name,
-                                               tag=partition_tag)
+                                          tag=partition_tag)
 
     @classmethod
     def bulk_insert_param(cls, collection_name, entities, partition_tag, ids=None, params=None, fields_info=None,
@@ -169,6 +170,10 @@ class Prepare:
         tag = partition_tag or default_partition_tag
         insert_request = milvus_types.InsertRequest(collection_name=collection_name, partition_name=tag)
 
+        for entity in entities:
+            if not entity.get("name", None) or not entity.get("values", None) or not entity.get("type", None):
+                raise ParamError("Missing param in entities, a field must have type, name and values")
+
         row_data = list()
         fields_name = list()
         fields_type = list()
@@ -185,7 +190,7 @@ class Prepare:
             for i in range(row_num):
                 row = []
                 for j in range(fields_len):
-                    row.append(entities[j]["values"][i])
+                    row.append(entities[j].get("values")[i])
                 row_data.append(row)
         else:
             # field name & type must match fields info
@@ -200,6 +205,10 @@ class Prepare:
                             match_flag = True
                             break
                         if field["name"] == entities[j]["name"]:
+                            if field["type"] != entities[j]["type"]:
+                                raise ParamError("Field type doesn't match. Collection field type is {},"
+                                                 "but entities field type is {}".format(field["type"],
+                                                                                        entities[j]["type"]))
                             location[field["name"]] = j
                             fields_type.append(entities[j]["type"])
                             match_flag = True
@@ -207,6 +216,10 @@ class Prepare:
 
                     else:
                         if field["name"] == entities[j]["name"]:
+                            if field["type"] != entities[j]["type"]:
+                                raise ParamError("Field type doesn't match. Collection field type is {},"
+                                                 "but entities field type is {}".format(field["type"],
+                                                                                        entities[j]["type"]))
                             location[field["name"]] = j
                             fields_type.append(entities[j]["type"])
                             match_flag = True
@@ -221,7 +234,7 @@ class Prepare:
                         continue
                     else:
                         loc = location[field_name]
-                        row.append(entities[loc]["values"][i])
+                        row.append(entities[loc].get("values")[i])
                 row_data.append(row)
 
         # fill row_data in bytes format
@@ -457,6 +470,7 @@ class Prepare:
     @classmethod
     def create_index__request(cls, collection_name, field_name, params):
         index_params = milvus_types.CreateIndexRequest(collection_name=collection_name, field_name=field_name)
+
         # index_params.collection_name = collection_name
         # index_params.field_name = field_name
 
@@ -465,6 +479,7 @@ class Prepare:
                 import json
                 return json.dumps(tv)
             return str(tv)
+
         if isinstance(params, dict):
             for tk, tv in params.items():
                 if tk == "dim":
@@ -497,11 +512,13 @@ class Prepare:
 
     @classmethod
     def load_partitions(cls, db_name, collection_name, partition_names):
-        return milvus_types.LoadPartitonRequest(db_name=db_name, collection_name=collection_name, partition_names= partition_names)
+        return milvus_types.LoadPartitonRequest(db_name=db_name, collection_name=collection_name,
+                                                partition_names=partition_names)
 
     @classmethod
     def release_partitions(cls, db_name, collection_name, partition_names):
-        return milvus_types.ReleasePartitionRequest(db_name=db_name, collection_name=collection_name, partition_names=partition_names)
+        return milvus_types.ReleasePartitionRequest(db_name=db_name, collection_name=collection_name,
+                                                    partition_names=partition_names)
 
     @classmethod
     def get_collection_stats_request(cls, collection_name):
@@ -513,4 +530,5 @@ class Prepare:
 
     @classmethod
     def drop_index_request(cls, collection_name, field_name, index_name):
-        return milvus_types.DropIndexRequest(db_name="", collection_name=collection_name, field_name=field_name, index_name=index_name)
+        return milvus_types.DropIndexRequest(db_name="", collection_name=collection_name, field_name=field_name,
+                                             index_name=index_name)
