@@ -98,6 +98,22 @@ class Milvus:
         self._kw = kwargs
         self._hooks = collections.defaultdict()
 
+        self._wait_for_healthy()
+
+    @check_connect
+    def _wait_for_healthy(self, timeout=30, retry=5):
+        with self._connection() as handler:
+            while retry > 0:
+                try:
+                    healthy = handler.fake_register_link(timeout)
+                    if healthy:
+                        return
+                except:
+                    pass
+                finally:
+                    retry -= 1
+            raise Exception("server is not healthy, please try again later")
+
     def __enter__(self):
         self._conn = self._pool.fetch()
         return self
@@ -309,9 +325,8 @@ class Milvus:
         """
         with self._connection() as handler:
             stats = handler.get_collection_stats(collection_name, timeout, **kwargs)
-            result = {}
-            for stat in stats:
-                result[stat.key] = stat.value
+            result = {stat.key: stat.value for stat in stats}
+            result["row_count"] = int(result["row_count"])
             return result
 
     @check_connect
@@ -366,7 +381,9 @@ class Milvus:
     @check_connect
     def drop_partition(self, collection_name, partition_tag, timeout=30):
         """
-        Deletes the specified partitions in a collection.
+        Deletes the specified partition in a collection. Note that the default partition
+        '_default' is not permitted to delete. When a partition deleted, all data stored in it
+        will be deleted.
 
         :param collection_name: The name of the collection to delete partitions from.
         :type  collection_name: str
@@ -374,13 +391,13 @@ class Milvus:
         :param partition_tag: The tag name of the partition to delete.
         :type  partition_tag: str
 
-        :return: None
-        :rtype: NoneType
-
         :param timeout: An optional duration of time in seconds to allow for the RPC. When timeout
                         is set to None, client waits until server response or error occur.
         :type  timeout: float
 
+        :return: None
+        :rtype: NoneType
+
         :raises:
             RpcError: If gRPC encounter an error
             ParamError: If parameters are invalid
@@ -418,15 +435,15 @@ class Milvus:
             return handler.has_partition(collection_name, partition_tag, timeout)
 
     @check_connect
-    def load_partitions(self, collection_name, partitions_names, timeout=30):
+    def load_partitions(self, collection_name, partition_names, timeout=30):
         """
         Load specified partitions from disk to memory.
 
         :param collection_name: The collection name which partitions belong to.
         :type  collection_name: str
 
-        :param partitions_names: The specified partitions to load.
-        :type  partitions_names: list[str]
+        :param partition_names: The specified partitions to load.
+        :type  partition_names: list[str]
 
         :param timeout: An optional duration of time in seconds to allow for the RPC. When timeout
                         is set to None, client waits until server response or error occur.
@@ -443,18 +460,18 @@ class Milvus:
         check_pass_param(collection_name=collection_name)
         with self._connection() as handler:
             return handler.load_partitions(db_name="", collection_name=collection_name,
-                                           partition_names=partitions_names, timeout=timeout)
+                                           partition_names=partition_names, timeout=timeout)
 
     @check_connect
-    def release_partitions(self, collection_name, partitions_name, timeout=30):
+    def release_partitions(self, collection_name, partition_names, timeout=30):
         """
         Clear partitions data from memory.
 
         :param collection_name: The collection name which partitions belong to.
         :type  collection_name: str
 
-        :param partitions_name: The specified partition to release.
-        :type  partitions_name: str
+        :param partition_names: The specified partition to release.
+        :type  partition_names: list[str]
 
         :param timeout: An optional duration of time in seconds to allow for the RPC. When timeout
                         is set to None, client waits until server response or error occur.
@@ -471,7 +488,7 @@ class Milvus:
         check_pass_param(collection_name=collection_name)
         with self._connection() as handler:
             return handler.release_partitions(db_name="", collection_name=collection_name,
-                                              partitions_name=partitions_name, timeout=timeout)
+                                              partition_names=partition_names, timeout=timeout)
 
     @check_connect
     def list_partitions(self, collection_name, timeout=30):
@@ -534,9 +551,11 @@ class Milvus:
     def create_index(self, collection_name, field_name, params, timeout=None, **kwargs):
         """
         Creates an index for a field in a specified collection. Milvus does not support creating multiple
-        indexes for a field. In a scenario where the field already has an index, if you create another one
-        that is equivalent (in terms of type and parameters) to the existing one, the server returns this
-        index to the client; otherwise, the server replaces the existing index with the new one.
+        indexes for a field. In a scenario where the field already has an index, if you create another one,
+        the server will replace the existing index files with the new ones.
+
+        Note that you need to call load_collection() or load_partitions() to make the new index take effect
+        on searching tasks.
 
         :param collection_name: The name of the collection to create field indexes.
         :type  collection_name: str
@@ -569,13 +588,6 @@ class Milvus:
                     "params": {"nlist": 1024}
                 }`
 
-            IVF_SQ8_HYBRID:
-                `{
-                    "metric_type": "L2",
-                    "index_type": "IVF_SQ8_HYBRID",
-                    "params": {"nlist": 1024}
-                }`
-
             BIN_IVF_FLAT:
                 `{
                     "metric_type": "JACCARD",
@@ -583,63 +595,41 @@ class Milvus:
                     "params": {"nlist": 1024}
                 }`
 
-            NSG:
-                `{
-                    "metric_type": "NSG",
-                    "index_type": "L2",
-                    "params": {"out_degree": 50, "candidate_pool_size": 50,
-                                "search_length": 50, "knng": 10}
-                }`
-
             HNSW:
                 `{
-                    "metric_type": "HNSW",
-                    "index_type": "L2",
+                    "metric_type": "L2",
+                    "index_type": "HNSW",
                     "params": {"M": 48, "efConstruction": 50}
                 }`
 
             RHNSW_FLAT:
                 `{
-                    "metric_type": "RHNSW_FLAT",
-                    "index_type": "L2",
+                    "metric_type": "L2",
+                    "index_type": "RHNSW_FLAT",
                     "params": {"M": 48, "efConstruction": 50}
                 }`
 
             RHNSW_PQ:
                 `{
-                    "metric_type": "RHNSW_PQ",
-                    "index_type": "L2",
+                    "metric_type": "L2",
+                    "index_type": "RHNSW_PQ",
                     "params": {"M": 48, "efConstruction": 50, "PQM": 8}
                 }`
 
             RHNSW_SQ:
                 `{
-                    "metric_type": "RHNSW_SQ",
-                    "index_type": "L2",
+                    "metric_type": "L2",
+                    "index_type": "RHNSW_SQ",
                     "params": {"M": 48, "efConstruction": 50}
                 }`
 
             ANNOY:
                 `{
-                    "metric_type": "ANNOY",
-                    "index_type": "L2",
+                    "metric_type": "L2",
+                    "index_type": "ANNOY",
                     "params": {"n_trees": 8}
                 }`
 
-            NGT_PANNG:
-                `{
-                    "metric_type": "NGT_PANNG",
-                    "index_type": "L2",
-                    "params": {"edge_size": 20, "forcedly_pruned_edge_size": 40, "selectively_pruned_edge_size": 10}
-                }`
-
-            NGT_ONNG:
-                `{
-                    "metric_type": "NGT_ONNG",
-                    "index_type": "L2",
-                    "params": {"edge_size": 20, "outgoing_edge_size": 10, "incoming_edge_size": 40}
-                }`
-
         :param timeout: An optional duration of time in seconds to allow for the RPC. When timeout
                         is set to None, client waits until server response or error occur.
         :type  timeout: float
@@ -773,10 +763,13 @@ class Milvus:
     @check_connect
     def flush(self, collection_names=None, timeout=None, **kwargs):
         """
-        Flushes data in the specified collections from memory to disk. When you insert or delete data,
-        the server stores the data in the memory temporarily and then flushes it to the disk at fixed
-        intervals. Calling flush ensures that the newly inserted data is visible and the deleted data
-        is no longer recoverable.
+        Internally, Milvus organizes data into segments, and indexes are built in a per-segment manner.
+        By default, a segment will be sealed if it grows large enough (according to segment size configuration).
+        If any index is specified on certain field, the index-creating task will be triggered automatically
+        when a segment is sealed.
+
+        The flush() call will seal all the growing segments immediately of the given collection,
+        and force trigger the index-creating tasks.
 
         :param collection_names: The name of collection to flush.
         :type  collection_names: list[str]
